From 8080beea858f42c5bbd116008ef7a9b01fb942a2 Mon Sep 17 00:00:00 2001
From: Lance Ju <lance@crenolab.com>
Date: Wed, 16 Apr 2014 00:17:52 +0800
Subject: [PATCH] Add the line to replace the database type. Replace the
 'mysql' options with 'db' options, makeing the config according to the
 database type.

---
 dockerfiles/images/gogits/deploy.sh | 25 ++++++++++++++++++-------
 1 file changed, 18 insertions(+), 7 deletions(-)

diff --git a/dockerfiles/images/gogits/deploy.sh b/dockerfiles/images/gogits/deploy.sh
index 4612a63da7..8c0e246b15 100644
--- a/dockerfiles/images/gogits/deploy.sh
+++ b/dockerfiles/images/gogits/deploy.sh
@@ -1,14 +1,25 @@
 # deploy.sh in gogits image, replace the configs and run gogs
 
-## Replace the mysql password
-MYSQL_PASSWORD=THE_MYSQL_PASSWORD
-MYSQL_ALIAS=DB
-MYSQL_PASSWORD_LINE=`awk '$0 ~ str{print NR+1}' str="USER = root" $GOPATH/src/github.com/gogits/gogs/conf/app.ini`
+## Replace the database password
+DB_TYPE=THE_DB_TYPE
+DB_PASSWORD=THE_DB_PASSWORD
+DB_ALIAS=DB
+DB_TYPE_LINE=`awk '$0 ~ str{print NR}' str="DB_TYPE = mysql" $GOPATH/src/github.com/gogits/gogs/conf/app.ini`
+DB_PASSWORD_LINE=`awk '$0 ~ str{print NR+1}' str="USER = root" $GOPATH/src/github.com/gogits/gogs/conf/app.ini`
 
-sed -i "${MYSQL_PASSWORD_LINE}s/.*$/PASSWD = $MYSQL_PASSWORD/g" $GOPATH/src/github.com/gogits/gogs/conf/app.ini 
+sed -i "${DB_TYPE_LINE}s/.*$/DB_TYPE = $DB_TYPE/g" $GOPATH/src/github.com/gogits/gogs/conf/app.ini 
+sed -i "${DB_PASSWORD_LINE}s/.*$/PASSWD = $DB_PASSWORD/g" $GOPATH/src/github.com/gogits/gogs/conf/app.ini 
 
-## Replace the mysql address and port
-# When using --link in docker run, the mysql image's info looks like this:
+if [ $DB_TYPE = "postgres" ]
+  then
+  # Add the postgres in gogs image.
+  apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys B97B0AFCAA1A47F044F244A07FCC7D46ACCC4CF8
+  apt-get -y -q install python-software-properties software-properties-common
+  apt-get -y -q install postgresql-9.3 postgresql-client-9.3 postgresql-contrib-9.3
+fi
+
+## Replace the database address and port
+# When using --link in docker run, the database image's info looks like this:
 # DB_PORT=tcp://172.17.0.2:3306
 # DB_PORT_3306_TCP_PORT=3306
 # DB_PORT_3306_TCP_PROTO=tcp